.. _crn_concept:

=====================
Common Random Numbers
=====================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------

- Variance reduction
- Counterfactual Analysis
